@@ -57,6 +57,14 @@ class User:
             'my_username': self.username
         }
 
+    @property
+    def to_dict(self):
+        return {
+            'public_key': self.public_key_hex,
+            'username_signature': self.username_signature,
+            'username': self.username
+        }
+
     @property
     def public_key_hex(self):
         if isinstance(self.public_key, PublicKey):
@@ -66,7 +74,7 @@ class User:
 
 
 class Service(User):
-    domain = 'http://0.0.0.0:8000'
+    domain = 'https://centeridentity.com'
 
     def __init__(self, wif, username):
         self.wif = wif
@@ -108,15 +116,15 @@ class Service(User):
         return base58.b58encode(binascii.unhexlify(final_key)).decode('utf-8')
 
     def api_call(self, endpoint, data):
-        api_token = requests.post(
+        response = requests.post(
             '{}{}'.format(self.domain, '/get-api-token'),
             json.dumps({
                 'username_signature': self.username_signature
             }), headers={'content-type': 'application/json'}).json()
-        if not api_token.get('api_uuid'):
-            return {'status': 'error', 'message': 'api error'}
+        if not response.get('api_uuid'):
+            raise Exception(response)
         request_signature = base64.b64encode(self.key.sign(hashlib.sha256(
-            api_token['api_uuid'].encode()).hexdigest().encode())).decode("utf-8")
+            response['api_uuid'].encode()).hexdigest().encode())).decode("utf-8")
         return requests.post(
             '{}{}'.format(self.domain, endpoint),
             json.dumps(data),
@@ -155,7 +163,7 @@ class Service(User):
         iv = enc[:16]
         cipher = AES.new(self.cipher_key, AES.MODE_CBC, iv)
         s = cipher.decrypt(enc[16:])
-        return json.loads(base64.b64decode(s[0:-ord(s.decode('latin1')[-1])]))
+        return json.loads(base64.b64decode(s[0:-ord(s.decode('latin1')[-1])]).decode())
 
 
 class CenterIdentity:
